@@ -1,6 +1,11 @@
 import datetime
 
-DATETIME_FORMATS = ["%Y-%m-%dT%H:%M:%S.%f%z", "%Y-%m-%dT%H:%M:%S.%f"]
+DATETIME_FORMATS = [
+    "%Y-%m-%dT%H:%M:%S.%f%z",
+    "%Y-%m-%dT%H:%M:%S.%f",
+    # For backwards compatibility to read timestamps created with a previous version.
+    "%Y-%m-%dT%H:%M:%S.Z",
+]
 
 
 def datetime_to_iso8601(dt: datetime.datetime) -> str:
